@@ -13,7 +13,7 @@ class Activity():
 
         self.define_properties()
 
-        if self.properties['Orientation'].value == 'Pro-Regime':
+        if self.properties['Orientation'].value == 'Pro-regime':
             self.actor = 'Regime'
         else:
             self.actor = 'Rebel'
