@@ -12,10 +12,10 @@ class Post():
 
         self.date = date
         self.now = datetime.now(dateutil.tz.tzlocal())
-        self.timezone_info = self.now.tzinfo
-        self.current_date = self.date.astimezone(self.timezone_info)
-        self.short_date = self.current_date.strftime('%Y-%m-%d')
-        self.time = self.current_date.strftime('%Y-%m-%d-%H%M')
+        self.local_timezone = self.now.tzinfo
+        self.local_date = self.date.astimezone(self.local_timezone)
+        self.short_date = self.local_date.strftime('%Y-%m-%d')
+        self.time = self.local_date.strftime('%Y-%m-%d-%H%M')
 
         self.link = self.item['link']
 
@@ -39,7 +39,12 @@ class Post():
 
         for term in ['reef', 'rif']:
             if self.content.contains(term):
-                self.province = self.content.locate(term, forward=True)
+                self.province = self.content.locate(term)
+
+        if not self.province:
+            sentence = Content(self.content.sentences[0])
+            if sentence.is_proper(0):
+                self.province = sentence.words[0]
 
         self.strategic_terms = [
             'clash',
@@ -82,6 +87,32 @@ class Post():
                     else:
                         self.strategic_sentences.append(sentence.text)
 
+        self.elements = [
+            ['mosque', 'mosques'],
+            ['prison', 'prisons'],
+            ['airport', 'airports'],
+            ['civilian airport', 'civilian airports'],
+            ['military airport', 'military airports'],
+            ['road', 'roads'],
+            ['street', 'streets'],
+            ['highway', 'highways'],
+            ['area', 'areas'],
+            ['neighborhood', 'neighborhoods'],
+            ['neighbourhood', 'neighbourhoods'],
+            ['village', 'villages'],
+            ['suburb', 'suburbs'],
+            ['town', 'towns'],
+            ['city', 'cities'],
+            ['province', 'provinces'],
+        ]
+
+        for sentence in self.strategic_sentences:
+            sentence = Content(sentence)
+
+            for element in self.elements:
+                if sentence.contains(element[1]):
+                    pass
+
         answer = self.layout()
 
         while True:
