@@ -180,9 +180,19 @@ class Property():
             self.value = self.number_check(self.value)
 
         if self.name == 'Total KIA':
+            self.value = self.total(
+                self.activity.properties['Pro-regime KIA'].value,
+                self.activity.properties['Anti-regime KIA'].value
+            )
+
             self.value = self.number_check(self.value)
 
         if self.name == 'Total WIA':
+            self.value = self.total(
+                self.activity.properties['Pro-regime WIA'].value,
+                self.activity.properties['Anti-regime WIA'].value
+            )
+
             self.value = self.number_check(self.value)
 
         if self.name == 'Outcome':
@@ -257,3 +267,11 @@ class Property():
                     continue
             else:
                 return answer
+
+    def total(self, pro, anti):
+        number = 0
+
+        for value in [pro, anti]:
+            if value:
+                number += int(value)
+        return str(number)
